% This file contains definitions that control the scripts

% The analysis can be run in both log or linear space.  Set logify to 0 to
% run in linear space.  Log space will increase the importance of the low
% expression miRNAs
LOGIFY = 1;

% Subsamples of all the dimension (RNAs for example) are used to expose
% batch effects that effect only a small number of the dimensions.  For
% microRNA we used a 5:10:300.  For RNA a much larger range is likely
% important
DIM_ARRAY = 5:10:300;

% At each iteration we do clustering based on pairs of Principal
% Components.  maxPCtoCheck tells us how many of the PCs to consider.
% Usually most of the variance is contained in first couple of PCs, here we
% use a conservative number of 5.
% Perhaps this should be changed to a % variance
MAX_PC_TO_CHECK = 5;

% plot level can be used to control how many plots are shown
% plot_level = 0, no plots
% plot_level = 1, only shown when p < 0.05 
% plot_level = 2, plots all comparisons
PLOT_LEVEL = 0;

% the number of replicates for each kmeans run; higher is more confident
N_REPLICATES = 10;


%%%%%%%%%%%%%%%%%%%%%%%%%% De Novo Parameters %%%%%%%%%%%%%%%%%%%%%%%%

% deNovo threshold
% this is the number that determines how "good" a grouping from K-means is.
% the range can be from -1 (terrible) to 1 (fantastic).  This is used for
% determining when to report and/or show results in the findBatchEffect.m script.
DN_THRESHOLD = 0.80;

% the highest number of clusters we'll allow
MAX_K = 10;

%%%%%%%%%%%%%%%%%%%%%%%%%% A Priori Parameters %%%%%%%%%%%%%%%%%%%%%%%

% This is the FDR rate used in the Benjamini Hochberg Yekutieli correction
% to determine how many, if any of the analysis identified significant
% non-random clusters (ie. a batch effect).
FDR = [0.05 0.01 0.001];

% always checking for 2 clusters.   Changing this to 3 will have deleterious
% effects. Has been included to help with later expansion.
K = 2; 
